@@ -19,16 +19,22 @@ from google.cloud import _http
 from google.cloud.storage import __version__
 
 
-_CLIENT_INFO = _http.CLIENT_INFO_TEMPLATE.format(__version__)
-
-
 class Connection(_http.JSONConnection):
     """A connection to Google Cloud Storage via the JSON REST API.
 
     :type client: :class:`~google.cloud.storage.client.Client`
     :param client: The client that owns the current connection.
+
+    :type client_info: :class:`~google.api_core.client_info.ClientInfo`
+    :param client_info: (Optional) instance used to generate user agent.
     """
 
+    def __init__(self, client, client_info=None):
+        super(Connection, self).__init__(client, client_info)
+
+        self._client_info.gapic_version = __version__
+        self._client_info.client_library_version = __version__
+
     API_BASE_URL = _http.API_BASE_URL
     """The base of the API call URL."""
 
@@ -37,5 +43,3 @@ class Connection(_http.JSONConnection):
 
     API_URL_TEMPLATE = "{api_base_url}/storage/{api_version}{path}"
     """A template for the URL of a particular API call."""
-
-    _EXTRA_HEADERS = {_http.CLIENT_INFO_HEADER: _CLIENT_INFO}
